<?php
/**
 * Webkul Software.
 *
 * @category  Webkul
 * @package   Webkul_Eshopsync
 * @author    Webkul Software Private Limited
 * @copyright Copyright (c) 2010-2017 Webkul Software Private Limited (https://webkul.com)
 * @license   https://store.webkul.com/license.html
 */

namespace Webkul\SalesforceConnector\Observer;
 
use Magento\Framework\Event\ObserverInterface;
use Magento\Framework\Event\Observer;
use Magento\Framework\App\RequestInterface;
 
class OnCustomerAddressSave implements ObserverInterface
{
 
    /** @var \Magento\Framework\Logger\Monolog */
    protected $_logger;

    /** @var \Webkul\Eshopsync\Helper\Connection */
    protected $_helperConnection;

    /** @var \Webkul\Eshopsync\Helper\Data */
    protected $_helperData;

    /** @var \Webkul\Eshopsync\Helper\Customer */
    protected $_helperCustomer;

    /** @var Magento\Framework\App\RequestInterface */
    protected $_request;

    /** @var \Webkul\Eshopsync\Model\CustomerFactory */
    protected $_eshopsyncCustomer;

    /**
     * @param \Psr\Log\LoggerInterface                   $loggerInterface
     * @param \Webkul\Eshopsync\Helper\Connection        $helperConnection
     * @param \Webkul\Eshopsync\Helper\Data              $helperData,
     * @param \Webkul\Eshopsync\Helper\Customer          $helperCustomer
     * @param RequestInterface                           $requestInterface
     * @param \Webkul\Eshopsync\Model\CustomerFactory    $eshopsyncCustomer
     */
    public function __construct(
        \Psr\Log\LoggerInterface $loggerInterface,
        \Webkul\SalesforceConnector\Helper\Connection $helperConnection,
        \Webkul\SalesforceConnector\Helper\Data $helperData,
        \Webkul\SalesforceConnector\Helper\Customer $helperCustomer,
        RequestInterface $requestInterface,
        \Webkul\SalesforceConnector\Model\CustomerFactory $eshopsyncCustomer
    ) {
    
        $this->_logger = $loggerInterface;
        $this->_helperConnection = $helperConnection;
        $this->_helperData = $helperData;
        $this->_helperCustomer = $helperCustomer;
        $this->_request = $requestInterface;
        $this->_eshopsyncCustomer = $eshopsyncCustomer;
    }
    /**
     * This is the method that fires when the event runs.
     *
     * @param Observer $observer
     */

    public function execute(Observer $observer)
    {
        // $customerId = $observer->getOrigCustomerDataObject()->getId(); work for backend only
        $customerAddress = $observer->getEvent()->getCustomerAddress()->getData();
        $customerId = $customerAddress['customer_id'];
       
        $controller = $this->_request->getControllerName();

        if (in_array($controller, ['index','address']) && $customerId) {
            
            $autoSync = $this->_helperData->getConfigValue('autoSync', 'autoSyncCustSync');
            if ($autoSync) {
                $this->_helperCustomer->exportSpecificCustomer($customerId);
            }
           
        }
        return true;
    }
}
